import { __decorate } from "tslib";
import { LifecycleMixin } from '@genesislcap/foundation-utils';
import { customElement, FoundationElement } from '@genesislcap/web-core';
import { FDC3 } from '../fdc3';
/**
 * fdc3-listener
 * @alpha
 */
let Fdc3Listener = class Fdc3Listener extends LifecycleMixin(FoundationElement) {
    constructor() {
        super(...arguments);
        this.intentConfig = [];
        this.channelConfig = [];
    }
    deepClone() {
        const copy = super.deepClone();
        if (this.intentConfig) {
            copy.intentConfig = this.intentConfig.map((c) => {
                const copyConfig = Object.assign({}, c);
                if (c.callback) {
                    copyConfig.callback = c.callback.bind(this);
                }
                return copyConfig;
            });
        }
        if (this.channelConfig) {
            copy.channelConfig = this.channelConfig.map((c) => {
                const copyConfig = Object.assign({}, c);
                if (c.callback) {
                    copyConfig.callback = c.callback.bind(this);
                }
                return copyConfig;
            });
        }
        return copy;
    }
    connectedCallback() {
        super.connectedCallback();
        if (window.fdc3) {
            const listeners = new Map();
            this.intentConfig.forEach((intent) => listeners.set(intent.intent, intent.callback));
            this.fdc3.addIntentListeners(listeners);
            this.channelConfig.forEach((c) => this.fdc3.addChannelListener(c.channelName, c.channelType, c.callback));
        }
    }
};
__decorate([
    FDC3
], Fdc3Listener.prototype, "fdc3", void 0);
Fdc3Listener = __decorate([
    customElement({
        name: 'fdc3-listener',
    })
], Fdc3Listener);
export { Fdc3Listener };
